==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/en_GB.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Usage survey",
    "Sent on: {on}" : "Sent on: {on}",
    "An error occurred while sending your report." : "An error occurred while sending your report.",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "App list <em>(for each app: name, version, is enabled?)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Database environment <em>(type, version, database size)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Encryption information <em>(is it enabled?, what is the default module)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Number of shares <em>(per type and permission setting)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Do you want to help us to improve Nextcloud by providing some anonymised data about your setup and usage? You can disable it at any time in the admin settings again.",
    "Not now" : "Not now",
    "Send usage" : "Send usage",
    "Never" : "Never",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "You can help improve Nextcloud by sending us some data about your current setup and usage.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymised first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server",
    "Send new report now" : "Send new report now",
    "Send usage survey monthly" : "Send usage survey monthly",
    "Data to send" : "Data to send",
    "Last report" : "Last report",
    "Sent on: %s" : "Sent on: %s",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "You can help us to improve Nextcloud be sending us some data about your current setup and usage.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "We take your privacy seriously. The data are anonymised and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "You can help us to improve Nextcloud by sending us some data about your current setup and usage.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "We take your privacy seriously. The data is anonymised and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/en_GB.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Usage survey",
    "Sent on: {on}" : "Sent on: {on}",
    "An error occurred while sending your report." : "An error occurred while sending your report.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "App list <em>(for each app: name, version, enabled status)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Database environment <em>(type, version, database size)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Encryption information <em>(is it enabled?, what is the default module)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Number of shares <em>(per type and permission setting)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>",
    "Help improve Nextcloud" : "Help improve Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Do you want to help us to improve Nextcloud by providing some anonymised data about your setup and usage? You can disable it at any time in the admin settings again.",
    "Not now" : "Not now",
    "Send usage" : "Send usage",
    "Never" : "Never",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "You can help improve Nextcloud by sending us some data about your current setup and usage.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymised first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server",
    "Send new report now" : "Send new report now",
    "Send usage survey monthly" : "Send usage survey monthly",
    "Data to send" : "Data to send",
    "Last report" : "Last report",
    "Sent on: %s" : "Sent on: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "App list <em>(for each app: name, version, is enabled?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "You can help us to improve Nextcloud be sending us some data about your current setup and usage.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "We take your privacy seriously. The data are anonymised and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "You can help us to improve Nextcloud by sending us some data about your current setup and usage.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "We take your privacy seriously. The data is anonymised and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server."
},
"nplurals=2; plural=(n != 1);");
